@@ -28,6 +28,9 @@ class File(Field):
     hide_value = True
 
     def __init__(self, **kwargs):
+        # Backwards compatibility
+        kwargs.setdefault('clean', kwargs.get('upload'))
+
         super(File, self).__init__(**kwargs)
 
     def str_to_py(self, **kwargs):
